<?php
/*
Plugin Name: Lightview Plus
Plugin URI: http://www.puzich.com/wordpress-plugins/lightview
Description: Seamless integration of Lightview (similar to Lightbox, Thickbox, Floatbox, Thickbox, Fancybox) to create a nice overlay to display images and videos without the need to change html. Further it shows youtube, vimeo and blip.tv videos in the overlay. Because Lightview by <a href="http://www.nickstakenburg.com/projects/lightview/">Nick Stakenburg</a> isn't licensed under the terms of gpl, it isn't included. Read installation instructions on <a href="http://www.puzich.com/wordpress-plugins/lightview-en">my website</a>.
Author: Puzich
Author URI: http://www.puzich.com
Version: 2.5.3.2
Put in /wp-content/plugins/ of your Wordpress installation

TODO: 
- install/uninstall routine wird nicht mehr aufgerufen (3.0)
- Video Button existiert nicht mehr
*/

if (!function_exists('is_admin')) {
    header('Status: 403 Forbidden');
    header('HTTP/1.1 403 Forbidden');
    exit();
}

global $wp_version;
define('LVPISWP27', version_compare($wp_version, '2.7', '>='));
define('LVPISWP28', version_compare($wp_version, '2.8', '>='));
define('LVPISWP29', version_compare($wp_version, '2.9', '>='));


class lightview_plus {
	
	// version
	var $version;

	// Nag Check Url
	var $chk_url = 'http://chk.puzich.com/';
	
	// put all options in
	var $options = array();
	
	// put all video tags in 
	var $video = array();
	
	// backup dir and file
	var $bkp_folder = '.lightview.bkp';
	
	function lightview_plus() {
		$this->__construct();
	}
	
	function __construct() {

		//load language
		if (function_exists('load_plugin_textdomain'))
			load_plugin_textdomain('lightviewplus', '/wp-content/plugins/lightview-plus/langs');
		
		// set version
		$this->version = $this->get_version();
		
		// get options	
		$this->options = get_option('lightview_plus');
		(!is_array($this->options) && !empty($this->options)) ? $this->options = unserialize($this->options) : $this->options = false;
		
		// install default options
		register_activation_hook(__FILE__, array(&$this, 'install'));
		
		// uninstall features
		register_deactivation_hook(__FILE__, array(&$this, 'uninstall'));
		
		// quick and dirty fix for wp 2.7
		if (LVPISWP27 == true) {
			add_action('admin_head', array(&$this, 'backup_before_update'), 10, 2);
		}
		
		// more setup links
		add_filter('plugin_row_meta', array(&$this, 'register_plugin_links'), 10, 2);
		
		// nagscreen at plugins page
		add_action('after_plugin_row', array(&$this, 'plugin_version_nag'));
		
		// add wp-filter
		add_filter('the_content', array(&$this, 'change_content'), 150);
		
		// add wp-action
		// use wp_enqueue_scripts from WP2.8 and above
		if (function_exists('wp_enqueue_scripts')) {
			add_action('wp_enqueue_scripts', array(&$this, 'enqueueJS'));
			add_action('wp_enqueue_scripts', array(&$this, 'enqueueCSS'));
		} else {
			add_action('wp_head', array(&$this, 'add_header'));
		}
		add_action('admin_menu', array(&$this, 'AdminMenu'));
		
		//add wp-shortcodes
		if($this->options['load_gallery'] && LVPISWP28 == true)
			add_filter('attachment_link', array(&$this, 'direct_image_urls_for_galleries'), 10, 2);
					
		// add MCE Editor Button
		if($this->options['show_video']) {
			add_action('init', array(&$this, 'mceinit'));
			add_action('admin_print_scripts', array(&$this, 'add_admin_header'));
		}
		
		// define object targets and links
		$this->video['default']['target'] = '<a href="###EMBEDURL###" title="###VIDEOTITLE### :: :: width: ###WIDTH###, height: ###HEIGHT###" class="lightview" rel="###MEDIATYPE###"><span class="lvp_previewimage" style="width:###PREVIEWWIDTH###px;"><img src="###IMAGE###" width="###PREVIEWWIDTH###" height="###PREVIEWHEIGHT###" alt="###TITLE###" /><span class="lvp_playbutton" style="left: ###LEFT###px; top: ###TOP###px;"> ▶ </span></span></a><br />';
		$this->video['default']['feed']   = '<img src="###IMAGE###" width="###PREVIEWWIDTH###" height="###PREVIEWHEIGHT###" alt="###TITLE###" />';
		$this->video['default']['link']   = "<a title=\"###VIDEOTITLE###\" href=\"###LINK### \">###PROVIDER### ###SEPERATOR######TITLE###</a>";
		
		$this->video['youtube']['iphone'] = '<object width="###WIDTH###" height="###HEIGHT###"><param name="movie" value="http://www.youtube.com/v/###VIDEOID###"></param><embed src="http://www.youtube.com/v/###VIDEOID###" type="application/x-shockwave-flash" width="###WIDTH###" height="###HEIGHT###"></embed></object><br />';
		
		$this->video['video']['flash']['target'] = "<object id=\"flowplayer\" width=\"###WIDTH###\" height=\"###HEIGHT###\" data=\"" . get_option('siteurl') . "/wp-content/plugins/lightview-plus/flowplayer/flowplayer-3.1.1.swf\" type=\"application/x-shockwave-flash\"> <param name=\"movie\" value=\"" . get_option('siteurl') . "/wp-content/plugins/lightview-plus/flowplayer/flowplayer-3.1.1.swf\" /> <param name=\"allowfullscreen\" value=\"true\" /> <param name=\"flashvars\" value='config={\"clip\":\"###VIDEOID###\"}' /></object>"; 		
		$this->video['video']['quicktime']['target'] = "<object classid=\"clsid:02BF25D5-8C17-4B23-BC80-D3488ABDDC6B\" codebase=\"http://www.apple.com/qtactivex/qtplugin.cab\" width=\"" .  $this->options['video_width'] . "\" height=\"" . 	$this->video['local']['quicktime']['height'] . "\"><param name=\"src\" value=\"".get_option('siteurl')."###VIDEOID###\" /><param name=\"autoplay\" value=\"false\" /><param name=\"pluginspage\" value=\"http://www.apple.com/quicktime/download/\" /><param name=\"controller\" value=\"true\" /><!--[if !IE]> <--><object data=\"".get_option('siteurl')."###VIDEOID###\" width=\"" . $this->options['video_width'] . "\" height=\"" . 	$this->video['local']['quicktime']['height'] . "\" type=\"video/quicktime\"><param name=\"pluginurl\" value=\"http://www.apple.com/quicktime/download/\" /><param name=\"controller\" value=\"true\" /><param name=\"autoplay\" value=\"false\" /></object><!--> <![endif]--></object><br />";
		$this->video['video']['target'] = "<object classid=\"clsid:22D6f312-B0F6-11D0-94AB-0080C74C7E95\" codebase=\"http://activex.microsoft.com/activex/controls/mplayer/en/nsmp2inf.cab#Version=6,4,7,1112\" width=\"".GENERAL_WIDTH."\" height=\"".VIDEO_HEIGHT."\" type=\"application/x-oleobject\"><param name=\"filename\" value=\"".get_option('siteurl')."###VIDEOID###\" /><param name=\"autostart\" value=\"false\" /><param name=\"showcontrols\" value=\"true\" /><!--[if !IE]> <--><object data=\"".get_option('siteurl')."###VIDEOID###\" width=\"".GENERAL_WIDTH."\" height=\"".VIDEO_HEIGHT."\" type=\"application/x-mplayer2\"><param name=\"pluginurl\" value=\"http://www.microsoft.com/Windows/MediaPlayer/\" /><param name=\"ShowControls\" value=\"true\" /><param name=\"ShowStatusBar\" value=\"true\" /><param name=\"ShowDisplay\" value=\"true\" /><param name=\"Autostart\" value=\"0\" /></object><!--> <![endif]--></object><br />";
		$this->video['video']['link'] = "<a title=\"Local Video\" href=\"".get_option('siteurl')."###VIDEOID###\">Download Video</a>";
	}
	
	function register_plugin_links($links, $file) {
		$base = plugin_basename(__FILE__);
		if ($file == $base) {
			$links[] = '<a href="options-general.php?page=' . $base .'">' . __('Settings','lightviewplus') . '</a>';
			$links[] = '<a href="http://www.puzich.com/wordpress-plugins/lightview">' . __('Support','lightviewplus') . '</a>';
			$links[] = '<a href="http://www.puzich.com/go/donate/">' . __('Donate with PayPal','lightviewplus') . '</a>';
			$links[] = '<a href="http://www.puzich.com/go/wishlist/">' . __('Donate with Amazon Wishlist','lightviewplus') . '</a>';
		}
		return $links;
	}
	
	// quick and dirty fix for wp2.7/auto update: seems that there is no hook during the update system that can be used
	function backup_before_update() {
		if( preg_match('/upgrade-plugin(.*)plugin=lightview-plus/i', $_SERVER['QUERY_STRING']) ) {
			$this->uninstall();
		}
	}

	// nagscreen at plugins page, based on the code of cformsII by Oliver Seidel
	function plugin_version_nag($plugin) {
		if (preg_match('/lightview-plus/i',$plugin)) {
			$checkfile = $this->chk_url . 'lightview-plus.' . $this->version . '.chk';
			$this->plugin_version_get($checkfile, $this->version);
		}
	}
	
	function plugin_version_get($checkfile, $version, $tr=false) {
		$vcheck = wp_remote_fopen($checkfile);
		
		if($vcheck) {
			$status = explode('@', $vcheck);
			$theVersion = $status[1];
			$theMessage = $status[3];
			
			if( $theMessage ) {
				if($tr == true)
					echo '</tr><tr>';
			
				if(version_compare($theVersion, $version) == 0) {
					$msg = __("Notice for:", "lightviewplus");
				} else {
					$msg = __("Update-Notice for:", "lightviewplus");
				}
				
				$msg .= ' <strong> Version '.$theVersion.'</strong><br />'.$theMessage;
				echo '<td colspan="5" class="plugin-update" style="line-height:1.2em;">'.$msg.'</td>';
			}
            
				if (version_compare($theVersion, $version) == 1) {
					$checkfile = $this->chk_url . 'lightview-plus.' . $theVersion . '.chk';
					$this->plugin_version_get($checkfile, $theVersion, true);
				}
        }
    }

	// Returns the plugin version
	function get_version() {
		if(!function_exists('get_plugin_data')) {
			if(file_exists(ABSPATH . 'wp-admin/includes/plugin.php')) {
				require_once(ABSPATH . 'wp-admin/includes/plugin.php'); //2.3+
			} elseif (file_exists(ABSPATH . 'wp-admin/admin-functions.php')) {
				require_once(ABSPATH . 'wp-admin/admin-functions.php'); //2.1
			} else { 
				return "ERROR: couldn't get version";
			}
		}
		$data = get_plugin_data(__FILE__, false, false);
		
		return $data['Version'];
	}
	
	function install() {
		//add default options
		$default = array(
					'load_protoculous' => true,
					'load_from_google' => false,
					'load_gallery' => true,
					'show_video' => true,
					'backup_lightview' => true,
					'video_showlink' => true,
					'video_smallink' => true,
					'video_preview_width'=> '300',
					'video_width' => '500',
					'video_separator' => '- ',
					'video_showinfeed' => true,
					'video_debug' => false
					);
					
		if(!is_array($this->options)) {
			$this->options = array();
		}
		
		foreach($default as $k => $v) {
			if(empty($this->options[$k])) {
				$this->options[$k] = $v;
			}
		}
		
		// set options
		update_option('lightview_plus', serialize($this->options));
		
		// restore lightview javascript, if backup exists and not already installed
		$bkp_folder = dirname(__FILE__) . '/../' . $this->bkp_folder;
		if (!$this->check_javascript()) {				
			$this->restore_lightview();
		}	
		
		// delete backup folder
		if( is_writable($bkp_folder) )
			$this->delete_recursive($bkp_folder);
		
		return true;
	}
	
	function uninstall() {
		// backup lightview, if it exists
		if( $this->options['backup_lightview'] && $this->check_javascript() ) 
			$this->backup_lightview();
		
		return true;	
	}
	
	
	//backups lightview javascript
	function backup_lightview() {
		// lightview folders to copy
		$dirnames = array('css', 'images', 'js');
		$destination = dirname(__FILE__) . '/../' . $this->bkp_folder;
		
		if(is_writable(dirname(__FILE__).'/..')) {
			if(!is_dir($destination) ) {
				mkdir($destination, 0777);
			}
		} else {
			return false;
		}
		
		for($i=0; $i < count($dirnames); $i++) {
			// subfolder to copy
			$folder = $dirnames[$i];
			
			// source files with foldernames
			$source = dirname(__FILE__);
			$source .= "/";
			$source .= $folder;

			// copy files
			$this->copy_recursive($source, $destination.'/'.$folder);
		}
		
		return true;
	}
	
	// restores lightview javascript
	function restore_lightview() {	
		$source = dirname(__FILE__)  . '/../' . $this->bkp_folder;
		
		if(is_writable(dirname(__FILE__)) && is_dir($source)) {
			$this->copy_recursive($source, dirname(__FILE__));
		}
		
		return true;
	}
	
	function copy_recursive($source, $dest) {
		// Simple copy for a file
		if (is_file($source)) {
			$c = copy($source, $dest);
			chmod($dest, 0777);
			return $c;
		}
		
		// Make destination directory
		if (!is_dir($dest)) {
			$oldumask = umask(0);
			mkdir($dest, 0777);
			umask($oldumask);
		}
		
		// Loop through the folder
		$dir = dir($source);
		while (false !== $entry = $dir->read()) {
		// Skip pointers
			if ($entry == "." || $entry == "..") {
				continue;
			}

			// Deep copy directories
			if ($dest !== "$source/$entry") {
				$this->copy_recursive("$source/$entry", "$dest/$entry");
			}
		}
		
		// Clean up
		$dir->close();
		
		return true;
	}
	
	function delete_recursive($dirname)	{ 
		// recursive function to delete
		// all subdirectories and contents:
		if(is_dir($dirname)) $dir_handle=opendir($dirname);
		
		while($file=readdir($dir_handle)) {
			if( $file != "." && $file != ".." ) {
				if(!is_dir($dirname."/".$file)) {
					unlink ($dirname."/".$file);
				} else {
					$this->delete_recursive($dirname."/".$file);
				}
			}
		}

		closedir($dir_handle);
		rmdir($dirname);
		
		return true;
	}
	
	function check_javascript() {
		
		if(!is_dir(dirname(__FILE__).'/js')) {
			return false;
		}
		
		if(!file_exists(dirname(__FILE__).'/js/lightview.js')) {
			return false;
		}
		
		if(!is_dir(dirname(__FILE__).'/css')) {
			return false;
		}
		
		if(!file_exists(dirname(__FILE__).'/css/lightview.css')) {
			return false;
		}
		
		if(!is_dir(dirname(__FILE__).'/images')) {
			return false;
		}
		
		return true;
	}

	function change_content($content) {
		
		// makes a set of pictures to a gallery
		// taken from add-lightbox-title plugin! Gracias!
		$pattern['image'][0]		= "/(<a)([^\>]*?) href=('|\")([A-Za-z0-9\?=,%\/_\.\~\:-]*?)(\.bmp|\.gif|\.jpg|\.jpeg|\.png)('|\")([^\>]*?)>(.*?)<\/a>/i";
		$replacement['image'][0]	= '$1 href=$3$4$5$6$2$7>$8</a>';
		// [0] <a xyz href="...(.bmp|.gif|.jpg|.jpeg|.png)" zyx>yx</a> --> <a href="...(.bmp|.gif|.jpg|.jpeg|.png)" xyz zyx>yx</a>
		$pattern['image'][1]		= "/(<a href=)('|\")([A-Za-z0-9\?=,%\/_\.\~\:-]*?)(\.bmp|\.gif|\.jpg|\.jpeg|\.png)('|\")([^\>]*?)(>)(.*?)(<\/a>)/i";
		$replacement['image'][1]	= '$1$2$3$4$5 class="lightview" rel="gallery['.$GLOBALS['post']->ID.']"$6$7$8$9';
		// [1] <a href="...(.bmp|.gif|.jpg|.jpeg|.png)" xyz zyx>yx</a> --> <a href="...(.bmp|.gif|.jpg|.jpeg|.png)" class="lightview" rel="gallery[POST-ID]" xyz zyx>yx</a>
		$pattern['image'][2]		= "/(<a href=)('|\")([A-Za-z0-9\?=,%\/_\.\~\:-]*?)(\.bmp|\.gif|\.jpg|\.jpeg|\.png)('|\") rel=('|\")gallery([^\>]*?)('|\")([^\>]*?) rel=('|\")(gallery)([^\>]*?)('|\")([^\>]*?)(>)(.*?)(<\/a>)/i";
		$replacement['image'][2]	= '$1$2$3$4$5$9 rel=$10$11$12$13$14$15$16$17';
		// [2] <a href="...(.bmp|.gif|.jpg|.jpeg|.png)" rel="gallery[POST-ID]" xyz rel="(gallery)yxz" zyx>yx</a> --> <a href="...(.bmp|.gif|.jpg|.jpeg|.png)" xyz rel="(gallery)yxz" zyx>yx</a>  !!!
		$pattern['image'][3]		= "/(<a href=)('|\")([A-Za-z0-9\?=,%\/_\.\~\:-]*?)(\.bmp|\.gif|\.jpg|\.jpeg|\.png)('|\")([^\>]*?)(>)(.*?) title=('|\")(.*?)('|\")(.*?)(<\/a>)/i";
		$replacement['image'][3]	= '$1$2$3$4$5$6 title=$9$10$11$7$8 title=$9$10$11$12$13';
		// [3] <a href="...(.bmp|.gif|.jpg|.jpeg|.png)" xyz>yx title=yxz xy</a> --> <a href="...(.bmp|.gif|.jpg|.jpeg|.png)" xyz title=yxz>yx title=yxz xy</a>
		$pattern['image'][4]		= "/(<a href=)('|\")([A-Za-z0-9\?=,%\/_\.\~\:-]*?)(\.bmp|\.gif|\.jpg|\.jpeg|\.png)('|\")([^\>]*?) title=([^\>]*?) title=([^\>]*?)(>)(.*?)(<\/a>)/i";
		$replacement['image'][4]	= '$1$2$3$4$5$6 title=$7$9$10$11';
		// [4] <a href="...(.bmp|.gif|.jpg|.jpeg|.png)" xyz title=zxy xzy title=yxz>yx</a> --> <a href="...(.bmp|.gif|.jpg|.jpeg|.png)" xyz title=zxy xzy>yx</a>
		$content = preg_replace($pattern['image'], $replacement['image'], $content);
		
		// RegEx for Videos
		$pattern['video'][1] = "/\[(youtube|youtubehq|vimeo|bliptv|video) ([[:graph:]]+) (nolink)\]/";
		$pattern['video'][2] = "/\[(youtube|youtubehq|vimeo|bliptv|video) ([[:graph:]]+) ([[:print:]]+)\]/";
		$pattern['video'][3] = "/\[(youtube|youtubehq|vimeo|bliptv|video) ([[:graph:]]+)\]/";
		
		// does the video thing
		if($this->options['show_video']) {
			$content = preg_replace_callback($pattern['video'][1], array(&$this, 'video_callback'), $content);
			$content = preg_replace_callback($pattern['video'][2], array(&$this, 'video_callback'), $content);
			$content = preg_replace_callback($pattern['video'][3], array(&$this, 'video_callback'), $content);
		}
	
		return $content;
	}
	
	// video callback logic
	function video_callback($match) {
		$output = '';
		// insert plugin link
		if (!is_feed()) {
			switch ($match[1]) {
				case "youtube": 
				case "youtubehq": 
					if ($this->is_mobile() == true) {
						$output .= $this->video['youtube']['iphone'];
					} else {
						$output .= $this->video['default']['target']; 
					}
					break;
				case "vimeo": $output .= $this->video['default']['target']; break;
				case "bliptv": $output .= $this->video['default']['target']; break;
				case "google": $output .= $this->video['google']['target']; break;
				case "sevenload": $output .= $this->video['sevenload']['target']; break;
				case "revver": $output .= $this->video['revver']['target']; break;
				case "metacafe": $output .= $this->video['metacafe']['target']; break;
				case "myspace": $output .= $this->video['myspace']['target']; break;
				case "brightcove": $output .= $this->video['brightcove']['target']; break;
				case "aniboom": $output .= $this->video['aniboom']['target']; break;
				case "guba": $output .= $this->video['guba']['target']; break;
				case "gamevideo": $output .= $this->video['gamevideo']['target']; break;
				case "vsocial": $output .= $this->video['vsocial']['target']; break;
				case "garagetv": $output .= $this->video['garage']['target']; $match[3] = "nolink"; break;
				case "veoh": $output .= $this->video['veoh']['target']; break;
				case "video":
					if (preg_match("%([[:print:]]+).(mov|qt|MOV|QT)$%", $match[2])) { 
						$output .= $this->video['local']['quicktime']['target']; 
						break; 
						
					} elseif (preg_match("%([[:print:]]+).(wmv|mpg|mpeg|mpe|asf|asx|wax|wmv|wmx|avi|WMV|MPG|MPEG|MPE|ASF|ASX|WAX|WMV|WMX|AVI)$%", $match[2])) { 
						$output .= $this->video['local']['target']; 
						break; 
						
					} elseif (preg_match("%([[:print:]]+).(swf|flv|SWF|FLV)$%", $match[2])) { 
						$output .= $this->video['local']['flashplayer']['target']; 
						break; 
					}
					
				default: 
					break;
			}
			
			if ($this->options['video_showlink'] == true) {
				if ($match[3] != "nolink") {
					if ($this->options['video_smallink']) 
						$output .= "<small>";
					
					switch ($match[1]) {
						case "youtube": $output .= $this->video['default']['link']; break;
						case "youtubehq": $output .= $this->video['default']['link']; break;
						case "vimeo": $output .= $this->video['default']['link']; break;
						case "bliptv": $output .= $this->video['default']['link']; break;
						case "google": $output .= $this->video['google']['link']; break;
						case "sevenload": $output .= $this->video['sevenload']['link']; break;
						case "revver": $output .= $this->video['revver']['link']; break;
						case "metacafe": $output .= $this->video['metacafe']['link']; break;
						case "myspace": $output .= $this->video['myspace']['link']; break;
						case "brightcove": $output .= $this->video['brightcove']['link']; break;
						case "aniboom": $output .= $this->video['aniboom']['link']; break;
						case "guba": $output .= $this->video['guba']['link']; break;
						case "vsocial": $output .= $this->video['vsocial']['link']; break;
						case "veoh": $output .= $this->video['veoh']['link']; break;
						case "video": $output .= $this->video['video']['link']; break;
						default: break;
					}
					
					if ($this->options['video_smallink']) 
						$output .= "</small>";
				}
			}
		} elseif ($this->options['video_showinfeed'] == true) { 
			$output .= $this->video['default']['feed'];
			$output .= '<br />\n';
			$output .= __('[There is a video that cannot be displayed in this feed. ', 'lightviewplus').'<a href="'.get_permalink().'">'.__('Visit the blog entry to see the video.]','lightviewplus').'</a>';
		}
		
		// postprocessing
		// first replace video_separator
		$output = str_replace("###SEPERATOR###", $this->options['video_separator'], $output);
		
		// replace video IDs and text	
		if ($match[3] != "nolink") {
			$output = str_replace("###TITLE###", $match[3], $output);
		} else {
			$output = str_replace("###TITLE###", '', $output);
		}
		$output = str_replace("###VIDEOID###", $match[2], $output);
		
		
		// replace palceholder with videodata
		$videodata = $this->get_cached_videodata($match[1], $match[2]);
		$output = str_replace("###IMAGE###", $videodata['thumbnail'], $output); // Thumbnail
		$output = str_replace("###EMBEDURL###", $videodata['embedurl'], $output); // Embed URL
		$output = str_replace("###LINK###", $videodata['link'], $output); // Link
		$output = str_replace("###VIDEOTITLE###", $videodata['title'], $output); // Video Title
		$output = str_replace("###PROVIDER###", $videodata['provider'], $output);
		if(!empty($videodata['mediatype'])) {
			$output = str_replace("###MEDIATYPE###", $videodata['mediatype'], $output);
		} else {
			$output = str_replace("###MEDIATYPE###", 'flash', $output);
		}
				
		if(!empty($videodata['height']) && !empty($videodata['width'])) {
			$output = str_replace("###WIDTH###", $this->options['video_width'], $output); // Width
			$output = str_replace("###HEIGHT###", floor($this->options['video_width'] / $videodata['width'] * $videodata['height']), $output); // Height
			$output = str_replace("###PREVIEWWIDTH###", $this->options['video_preview_width'], $output); // Preview Width
			$output = str_replace("###PREVIEWHEIGHT###", floor($this->options['video_preview_width'] / $videodata['width'] * $videodata['height']), $output); // Preview Height
			$output = str_replace("###LEFT###", floor($this->options['video_preview_width'] / 2) - 50, $output); // left
			$output = str_replace("###TOP###", floor(($this->options['video_preview_width'] / $videodata['width'] * $videodata['height']) / 2) - 25, $output); // top
		}
		
		// add HTML comment
		$output .= "\n<!-- generated by WordPress Plugin Lightview Plus $this->version -->\n";
		
		// got errors during receiving videodata? Show nice placeholder
		if ($videodata['available'] == false) {
				$output = sprintf('<img src="'. @plugins_url('lightview-plus/img/novideo.png') .'" width="%s" height="%s" alt="'. __('Video not available', 'lightviewplus') .'" /><br />',
							$this->options['video_preview_width'],
							floor($this->options['video_preview_width'] / 640 * 360)
							);
		}	
		
		// show debug informations under the videos
		if($this->options['video_debug'] == true ) {
			$debug = sprintf('<div style="background-color:#FFC0CB; border:1px solid silver; color:#110000; margin:0 0 1.5em; overflow:auto; padding: 3px;">
								<strong>Provider:</strong> %s <br />
								<strong>Title:</strong> %s <br />
								<strong>Thumbnail URL:</strong> %s <br />
								<strong>Embed URL:</strong> %s <br />
								<strong>Link:</strong> %s <br />
								<strong>Width:</strong> %s px<br />
								<strong>Height:</strong> %s px<br />
								<strong>Got data @:</strong> %s<br />
							</div>',
							$videodata['provider'],
							$videodata['title'],
							$videodata['thumbnail'],
							$videodata['embedurl'],
							$videodata['link'],
							$videodata['width'],
							$videodata['height'],
							date('d.n.Y H:i:s', $videodata['timestamp'])
							);
							
			$output .= $debug;
		}
		
		return $output;
	}
	
	// get the video data out of the cache
	function get_cached_videodata($service, $id) {
		$videodata = get_post_meta($GLOBALS['post']->ID, '_lvp', true);
		
		// if no cached data available or data is older than 24 hours, refresh/get data from video provider
		if(empty($videodata[$service][$id]) || $videodata[$service][$id]['timestamp'] + (60 * 60 * 24) < time() ) {
			$videodata[$service][$id] = $this->get_videodata($service, $id);
			update_post_meta($GLOBALS['post']->ID, '_lvp', $videodata);
		}
		
		return $videodata[$service][$id];		
	}
	
	// puts the video data into cache
	function get_videodata($service, $id) {
		switch($service) {
			case "youtube":
			case "youtubehq":
				$api      = sprintf('http://gdata.youtube.com/feeds/api/videos/%s', $id);
				$xml      = @simplexml_load_string(wp_remote_fopen($api));
				
				if (is_object($xml)) {
					$media    = $xml->children('http://search.yahoo.com/mrss/');
					
					if($media->group->thumbnail) {
						$attribs  = $media->group->thumbnail[3]->attributes();
					
						$output['available']    = true;
						$output['provider']     = 'YouTube';
						$output['mediatype']	= 'flash';
						$output['title']	    = (string) $media->group->title;
						$output['embedurl']	    = sprintf('http://www.youtube.com/v/%s', $id);
						$output['thumbnail']    = (string) $attribs['url'];
						$output['width']        = (int) $attribs['width'];
						$output['height']       = (int) $attribs['height'];
						$output['link']         = sprintf('http://www.youtube.com/watch?v=%s', $id);
					
						// add autoplay
						$output['embedurl'] = sprintf('%s&amp;autoplay=1', $output['embedurl']);
					
						if($service == 'youtubehq')
							$output['embedurl'] = sprintf('%s&amp;ap=%%2526&amp;fmt%%3D22&amp;hd=1', $output['embedurl']);
					} else {
						$output['available'] = false;
					}
					
				} else {
					$output['available'] = false;
				}
				$output['timestamp'] = time();
				
				break;
			case "vimeo":
				// check if $id is numeric
				if(!is_numeric($id)) {
					$output['available'] = false;
					return $output;
				}
					
				// Get preview image from vimeo
				$api    = sprintf('http://vimeo.com/api/v2/video/%s.xml', $id);
				$video  = @simplexml_load_string(wp_remote_fopen($api));
				
				$outout = array();
				$output['available']    = true;
				$output['provider']     = 'Vimeo';
				$output['title']        = (string) $video->video->title;
				$output['embedurl']	    = (string) sprintf('http://player.vimeo.com/video/%s', $id);
				$output['mediatype']	= 'iframe';
				$output['thumbnail']    = (string) $video->video->thumbnail_large;
				$output['width']        = (int) $video->video->width;
				$output['height']       = (int) $video->video->height;
				$output['link']         = sprintf('http://www.vimeo.com/%s', $id);
				$output['timestamp'] = time();
				
				// add autoplay
				$output['embedurl'] = sprintf('%s&amp;autoplay=1', $output['embedurl']);
				
				// check response
				if(empty($output) || empty($output['width']) || empty($output['height']) || empty($output['thumbnail']) ) {
					$output['available'] = false;
					return $output;
				}
				
				break;
			case "bliptv":
				// require SimplePie
				require_once(ABSPATH . WPINC . '/feed.php');
				$api = sprintf('http://www.blip.tv/file/%s?skin=rss', $id);
				$namespace['media'] = 'http://search.yahoo.com/mrss/';
				$namespace['blip']  = 'http://blip.tv/dtd/blip/1.0';
				
				// fetch feed
				$rss = fetch_feed($api);
					
				if(is_wp_error($rss)) {
					$output['available'] == false;
					return $output;
				}
				
				// get items
				$item = $rss->get_item();
				
				// get media items
				$mediaGroup     = $item->get_item_tags($namespace['media'], 'group');
				$mediaContent   = $mediaGroup[0]['child'][$namespace['media']]['content'];
				
				// get blip items
				$blipThumbnail = $item->get_item_tags($namespace['blip'], 'thumbnail_src');
				$blipEmbedURL  = $item->get_item_tags($namespace['blip'], 'embedUrl');
					
				$output['available']    = true;
				$output['provider']     = 'Blip.TV';
				$output['title']        = (string) $rss->get_title();
				$output['embedurl']     = (string) $blipEmbedURL[0]['data'];
				$output['mediatype']	= 'flash';
				$output['thumbnail']    = (string) sprintf('http://a.images.blip.tv/%s', $blipThumbnail[0]['data']);
				$output['height']       = (int) $mediaContent[count($mediaContent)-1]['attribs']['']['height'];
				$output['width']        = (int) $mediaContent[count($mediaContent)-1]['attribs']['']['width'];
				$output['link']         = (string) $item->get_link();
				$output['timestamp'] = time();
				
				// add autoplay
				$output['embedurl'] = sprintf('%s&amp;autoStart=true', $output['embedurl']);
				
				// check response
				if(empty($output)) {
					$output['available'] = false;
					return $output;
				}
				
					
				break;
			case "video":
				break;
			default: break;
		}	
		return $output;
	}

	function is_mobile() {
		$uas = array ( 'iPhone', 'iPod', 'iPad', 'Android');

		foreach ( $uas as $useragent ) {
			$pattern = sprintf('/%s/', $useragent);
			if ( (bool) preg_match($pattern, $_SERVER['HTTP_USER_AGENT'])) {
				return true;
			} 
		}
		return false;
	}
	
	function add_header() {
		$path = get_option('siteurl')."/wp-content/plugins/lightview-plus";
		
		$script = "\n<!-- Lightview Plus Plugin $this->version -->\n";
		
		if ($this->options['load_protoculous']) {
			// load javascript librarys from google
			if ($this->options['load_from_google']) {
				$script .= "<script type='text/javascript' src='http://ajax.googleapis.com/ajax/libs/prototype/1/prototype.js'></script>\n";
				$script .= "<script type='text/javascript' src='http://ajax.googleapis.com/ajax/libs/scriptaculous/1/scriptaculous.js?load=effects'></script>\n";
			} else {
				$script .= "<script type='text/javascript' src='$path/libs/prototype.js'></script>\n";
				$script .= "<script type='text/javascript' src='$path/libs/scriptaculous.js?load=effects'></script>\n";
			}
		}
		
		$script .= "<link rel=\"stylesheet\" type=\"text/css\" href=\"$path/css/lightview.css\" media=\"screen\" />\n";
		$script .= "<script type='text/javascript' src='$path/js/lightview.js'></script>\n";
		$script .= "<link rel=\"stylesheet\" type=\"text/css\" href=\"$path/style.css\" media=\"screen\" />\n";
		
		$script .= "<!-- Lightview Plus Plugin $this->version -->\n";	
		
		echo $script;
	}
	
	function enqueueJS() {
		wp_enqueue_script('lightview', plugins_url('/lightview-plus/js/lightview.js'), array('prototype', 'scriptaculous'), $this->version, false);
	
		if ($this->options['load_protoculous']) {
			wp_deregister_script('prototype');
			wp_deregister_script('scriptaculous');
			// load javascript librarys from google
			if ($this->options['load_from_google']) {
				wp_enqueue_script('prototype', 'http://ajax.googleapis.com/ajax/libs/prototype/1.6.1/prototype.js', false, '1.6.1', false);
				wp_enqueue_script('scriptaculous', 'http://ajax.googleapis.com/ajax/libs/scriptaculous/1.8.3/scriptaculous.js', array('prototype'), '1.8.3', false);
			} else {
				wp_enqueue_script('prototype', plugins_url('/lightview-plus/libs/prototype.js'), false, '1.6.1', false);
				wp_enqueue_script('scriptaculous', plugins_url('/lightview-plus/libs/scriptaculous.js'), array('prototype'), '1.8.3', false);
			}
		}
	}
	
	function enqueueCSS() {
		wp_enqueue_style('lightview', plugins_url('/lightview-plus/css/lightview.css'), false, $this->version, 'screen');
		wp_enqueue_style('lightview_plus', plugins_url('/lightview-plus/style.css'), false, $this->version, 'screen');		
	}
	
	function AdminMenu() {
		add_options_page('Lightview Plus', (LVPISWP28 ? '<img src="' . @plugins_url('lightview-plus/img/icon.png') . '" width="10" height="10" alt="Lightview Plus - Icon" /> ' : '') . 'Lightview Plus', 8, 'lightview-plus/'.basename(__FILE__), array(&$this, 'OptionsMenu'));	
	}

	function OptionsMenu() {
		
		if (!empty($_POST)) {
		
			// option 'load_protoculous'
			if($_POST['load_protoculous'] == 'true') {
				$this->options['load_protoculous'] = true;
			} else {
				$this->options['load_protoculous'] = false;
			}
			
			// option 'load_from_google'
			// loads prototype / scriptaculous from googleajax
			if($_POST['load_from_google'] == 'true') {
				$this->options['load_from_google'] = true;
			} else {
				$this->options['load_from_google'] = false;
			}
		
			// option 'load_gallery'
			if($_POST['load_gallery'] == 'true') {
				$this->options['load_gallery'] = true;
			} else {
				$this->options['load_gallery'] = false;
			}
		
			// option 'show_video'
			if($_POST['show_video'] == 'true') {
				$this->options['show_video'] = true;
			} else {
				$this->options['show_video'] = false;
			}
			
			// option 'backup_lightview'
			if($_POST['backup_lightview'] == 'true') {
				$this->options['backup_lightview'] = true;
			} else {
				$this->options['backup_lightview'] = false;
			}
			
			// option 'video_showlink'
			if($_POST['video_showlink'] == 'true') {
				$this->options['video_showlink'] = true;
			} else {
				$this->options['video_showlink'] = false;
			}
			
			// option 'video_smallink'
			if($_POST['video_smallink'] == 'true') {
				$this->options['video_smallink'] = true;
			} else {
				$this->options['video_smallink'] = false;
			}
			
			//option 'video_separator'
			if(!empty($_POST['video_separator'])) {
				$this->options['video_separator'] = $_POST['video_separator'];
			}
			
			//option 'video_preview_width'
			if(!empty($_POST['video_preview_width'])) {
				$this->options['video_preview_width'] = $_POST['video_preview_width'];
			}
			
			//option 'video_width'
			if(!empty($_POST['video_width'])) {
				$this->options['video_width'] = $_POST['video_width'];
			}
			
			// option 'video_showinfeed'
			if($_POST['video_showinfeed'] == 'true') {
				$this->options['video_showinfeed'] = true;
			} else {
				$this->options['video_showinfeed'] = false;
			}
			
			// option 'video_debug'
			if($_POST['video_debug'] == 'true') {
				$this->options['video_debug'] = true;
			} else {
				$this->options['video_debug'] = false;
			}
		
			// update options
			update_option('lightview_plus', serialize($this->options));
		
			// echo successfull update
			echo '<div id="message" class="updated fade"><p><strong>' . __('Options saved.', 'lightviewplus') . '</strong></p></div>';
		}
		
		?>
		<div class="wrap">
			<h2>Lightview Plus</h2>
		
			<?php 
			// echo error if lightview js / css isn't copied to plugin dir
			
			if(!$this->check_javascript()) {
				echo '<div id="message" class="error"><p><strong>' . __('Lightview Javascript and/or CSS isn\'t copied to the plugin directory. See installation instructions for further details.', 'lightviewplus') . '</strong></p></div>';
			}
			?>
					
				<?php // Donate ?>
				<h3><?php _e('Donation', 'lightviewplus'); ?></h3>
				<table>
				<tbody>
				<tr>
					<td>
						<?php _e('Lightview Plus has required a great deal of time and effort to develop. If it\'s been useful to you then you can support this development by making a small donation. This will act as an incentive for me to carry on developing it, providing countless hours of support, and including any enhancements that are suggested. If you don\'t have a clue how much you want to spend, the average of the last donations were €8. But every other amount is welcome. Please note, that PayPal takes for every transaction round about €0.50. So every donation below €1 is only a donation to PayPal ;-) Further you have the options to have a look at my amazon wishlist.', 'lightviewplus'); ?><br />
						<center><a href="http://www.puzich.com/go/donate"><img src="<?php echo get_option('siteurl'); ?>/wp-content/plugins/lightview-plus/img/donate.gif" /> <?php _e('Donate via PayPal!', 'lightviewplus'); ?></a> or <a href="http://www.puzich.com/go/wishlist/"><?php _e('make a gift with Amazon', 'lightviewplus') ?></a></center>
					</td>
				</tr>
				</tbody>
				</table>
			
		
				<h3><?php _e('General Settings', 'lightviewplus'); ?></h3>
			
				<form action="options-general.php?page=lightview-plus/lightview-plus.php" method="post">
				<table class="form-table">
				<tbody>
					<tr valign="top">
						<th scope="row">
							<label>
								<?php 
									if ( LVPISWP28 ) {
										_e('Load newest prototype/scriptacolous javascript library version brought with lightview-plus?', 'lightviewplus');
									} else {
										_e('load prototype/scriptacolous javascript Library?', 'lightviewplus');
									}
								?>
							</label>
						</th>
						<td>			
							<select name="load_protoculous" size="1">
							<option value="true" <?php if ($this->options['load_protoculous'] == true ) { ?>selected="selected"<?php } ?>><?php _e('yes', 'lightviewplus'); ?></option>
							<option value="false" <?php if ($this->options['load_protoculous'] == false ) { ?>selected="selected"<?php } ?>><?php _e('no', 'lightviewplus'); ?></option>
							</select>
							
							<br />
							<?php _e('Please, deactivate this, if you know what you are doing. It loads a version of Prototype and Scriptaculous that works best with lightview', 'lightviewplus'); ?>
						</td>
					</tr>
					
					<?php // load JS Libs from Google?  ?>
					<tr valign="top">
						<th scope="row">
							<label><?php _e('Load Prototype & Scriptacolous Libraries from Google?', 'lightviewplus')?></label>
						</th>
						<td>			
							<select name="load_from_google" size="1">
							<option value="true" <?php if ($this->options['load_from_google'] == true ) { ?>selected="selected"<?php } ?>><?php _e('yes', 'lightviewplus'); ?></option>
							<option value="false" <?php if ($this->options['load_from_google'] == false ) { ?>selected="selected"<?php } ?>><?php _e('no', 'lightviewplus'); ?></option>
							</select>
							
							<br />
							<?php _e('Choose if you want to load prototype and scriptaculous from Google and get it always in the newest version. Otherwise the local versions of prototype and scriptaculous will load.', 'lightviewplus'); ?>
						</td>
					</tr>
				
					<?php // Activate Gallery? ?>
					<?php if( LVPISWP27 == true ) : ?>
					<tr valign="top">
						<th scope="row">
							<label><?php _e('Activate Lightview for [gallery]?', 'lightviewplus')?></label>
						</th>
						<td>
							<select name="load_gallery" size="1">
							<option value="true" <?php if ($this->options['load_gallery'] == true ) { ?>selected="selected"<?php } ?>><?php _e('yes', 'lightviewplus'); ?></option>
							<option value="false" <?php if ($this->options['load_gallery'] == false ) { ?>selected="selected"<?php } ?>><?php _e('no', 'lightviewplus'); ?></option>
							</select>
							
							<br />
							<?php _e('If activated, it shows the wordpress gallery with lightview', 'lightviewplus'); ?>
						</td>
					</tr>
					<?php endif; ?>
				
					<?php // Activate Movies? ?>
					<tr valign="top">
						<th scope="row">
							<label><?php _e('Activate Lightview for Videos?', 'lightviewplus')?></label>
						</th>
						<td>
							<select name="show_video" size="1">
							<option value="true" <?php if ($this->options['show_video'] == true ) { ?>selected="selected"<?php } ?>><?php _e('yes', 'lightviewplus'); ?></option>
							<option value="false" <?php if ($this->options['show_video'] == false ) { ?>selected="selected"<?php } ?>><?php _e('no', 'lightviewplus'); ?></option>
							</select>
							
							<br />
							<?php _e('Implements the video function. ATTENTION: It only works, if you do not have the embedded video plugin activated', 'lightviewplus'); ?>
						</td>
					</tr>
					
					<?php // Create Backup of Lightview Javascript if plug-in deactivates? ?>
					<tr valign="top">
						<th scope="row">
							<label><?php _e('Backup Lightview Javascript during Update?', 'lightviewplus')?></label>
						</th>
						<td>
							<select name="backup_lightview" size="1">
							<option value="true" <?php if ($this->options['backup_lightview'] == true ) { ?>selected="selected"<?php } ?>><?php _e('yes', 'lightviewplus'); ?></option>
							<option value="false" <?php if ($this->options['backup_lightview'] == false ) { ?>selected="selected"<?php } ?>><?php _e('no', 'lightviewplus'); ?></option>
							</select>
							
							<br />
							<?php _e('Backups the lightview javascript files for upgrade-reasons. After uprading to a new lightview-plus version, it is needless to copy the javascript files back in the plugin directory. ', 'lightviewplus'); ?>
						</td>
					</tr>
					
					
				</tbody>
				</table>
				
				<h3><?php _e('Video Options', 'lightviewplus'); ?></h3>
				
				<table class="form-table">
				<tbody>
					<?php // Show link under Videos? ?>
					<tr valign="top">
						<th scope="row">
							<label><?php _e('Show Links under videos?', 'lightviewplus')?></label>
						</th>
						<td>
							<select name="video_showlink" size="1">
							<option value="true" <?php if ($this->options['video_showlink'] == true ) { ?>selected="selected"<?php } ?>><?php _e('yes', 'lightviewplus'); ?></option>
							<option value="false" <?php if ($this->options['video_showlink'] == false ) { ?>selected="selected"<?php } ?>><?php _e('no', 'lightviewplus'); ?></option>
							</select>
							
							<br />
							<?php _e('Show a link to the original site of the video', 'lightviewplus'); ?>
						</td>
					</tr>
					
					<?php // Show link under videos in small? ?>
					<tr valign="top">
						<th scope="row">
							<label><?php _e('Show a small Link under the Video?', 'lightviewplus'); ?></label>
						</th>
						<td>
							<select name="video_smallink" size="1">
							<option value="true" <?php if ($this->options['video_smallink'] == true ) { ?>selected="selected"<?php } ?>><?php _e('yes', 'lightviewplus'); ?></option>
							<option value="false" <?php if ($this->options['video_smallink'] == false ) { ?>selected="selected"<?php } ?>><?php _e('no', 'lightviewplus'); ?></option>
							</select>
							
							<br />
							<?php _e('If no, it will show a bigger text', 'lightviewplus'); ?>
						
						
						</td>
					</tr>
					
					<?php // Linktext ?>
					<tr valign="top">
						<th scope="row">
							<label><?php echo _e('Separator', 'lightviewplus'); ?></label>
						</th>
						<td>
							<input type="text" value="<?php echo $this->options['video_separator'] ?>" name="video_separator" id="video_separator" size="5" maxlength="3" />
							<br />
							<?php _e('Defines the separator between the service (eg. YouTube) and your comment', 'lightviewplus'); ?>
						</td>
					</tr>
					
					<?php // Show in Feed? ?>
					<tr valign="top">
						<th scope="row">
							<label><?php echo _e('Show in Feed?', 'lightviewplus'); ?></label>
						</th>
						<td>
							<select name="video_showinfeed" size="1">
							<option value="true" <?php if ($this->options['video_showinfeed'] == true ) { ?>selected="selected"<?php } ?>><?php _e('yes', 'lightviewplus'); ?></option>
							<option value="false" <?php if ($this->options['video_showinfeed'] == false ) { ?>selected="selected"<?php } ?>><?php _e('no', 'lightviewplus'); ?></option>
							</select>
							
							<br />
							<?php _e('You can choose, if you want to show the video in the feed. Currently, it is only possible to show a link to the video', 'lightviewplus'); ?>
						</td>
					</tr>
					
					<?php // Video Preview Image Width ?>
					<tr valign="top">
						<th scope="row">
							<label><?php _e('Video Preview Width', 'lightviewplus'); ?>  (250px - 800px)</label>
						</th>
						<td>
							<input type="text" value="<?php echo $this->options['video_preview_width'] ?>" name="video_preview_width" id="video_preview_width" size="5" maxlength="3" />
							<br />
							<?php _e('Choose the width of the preview images for the videos', 'lightviewplus'); ?>
						</td>
					</tr>
					
					<?php // Video Width ?>
					<tr valign="top">
						<th scope="row">
							<label><?php _e('Video Width', 'lightviewplus'); ?>  (250px - 800px)</label>
						</th>
						<td>
							<input type="text" value="<?php echo $this->options['video_width'] ?>" name="video_width" id="video_width" size="5" maxlength="3" />
							<br />
							<?php _e('You can choose, what width the video and image have', 'lightviewplus'); ?>
						</td>
					</tr>
					
					<?php // Video Debug ?>
					<tr valign="top">
						<th scope="row">
							<label><?php echo _e('Show Video Debug Infos', 'lightviewplus'); ?></label>
						</th>
						<td>
							<select name="video_debug" size="1">
							<option value="true" <?php if ($this->options['video_debug'] == true ) { ?>selected="selected"<?php } ?>><?php _e('yes', 'lightviewplus'); ?></option>
							<option value="false" <?php if ($this->options['video_debug'] == false ) { ?>selected="selected"<?php } ?>><?php _e('no', 'lightviewplus'); ?></option>
							</select>
							
							<br />
							<?php _e('Shows video informations, like embed url or image url of the video. Only for debug!', 'lightviewplus'); ?>
						</td>
					</tr>
					
				</tbody>	
				</table>
				
				<p class="submit">
				<input type="submit" name="Submit" value="<?php _e('Update Options »', 'lightviewplus'); ?>" />
				</p>
				</form>
				
				<p><small>Video Icon from <a href="http://www.famfamfam.com">famfamfam </a>. Special thanks to Jovelstefan and his plugin <a href="http://wordpress.org/extend/plugins/embedded-video-with-link/">Embedded Video with Link</a>, which inspired me.</small></p>
			
	    </div>
	<?php
	}
	
	function mcebutton($buttons) {
		array_push($buttons, "|", "lightviewplus");
		return $buttons;
	}

	function mceplugin($ext_plu) {
		if (is_array($ext_plu) == false) {
			$ext_plu = array();
		}
		
		$url = get_option('siteurl')."/wp-content/plugins/lightview-plus/editor_plugin.js";
		$result = array_merge($ext_plu, array("lightviewplus" => $url));
		return $result;
	}

	function mceinit() {
		if (function_exists('load_plugin_textdomain')) load_plugin_textdomain('lightviewplus', dirname(__FILE__).'/langs');
		if ( 'true' == get_user_option('rich_editing') ) {
			add_filter('mce_external_plugins', array(&$this, 'mceplugin'), 0);
			add_filter("mce_buttons", array(&$this, 'mcebutton'), 0);
		}
	}

	function add_admin_header() {
		echo "<script type='text/javascript' src='".get_option('siteurl')."/wp-content/plugins/lightview-plus/lightview-plus.js'></script>\n";
	}
	
	function direct_image_urls_for_galleries( $link, $id ) {
		if ( is_admin() ) return $link;

		$mimetypes = array( 'image/jpeg', 'image/png', 'image/gif' );

		$post = get_post( $id );

		if ( in_array( $post->post_mime_type, $mimetypes ) )
			return wp_get_attachment_url( $id );
		else
			return $link;
	}

}

//initalize class
if (class_exists('lightview_plus'))
	$lightview_plus = new lightview_plus();
	
/* 
   if function simplexml_load_string is not compiled into php
   use simplexml.class.php
*/
if(!function_exists("simplexml_load_string")) {
	require_once('libs/simplexml.class.php');
	
	function simplexml_load_string($file)
	{
		$sx = new simplexml;
		return $sx->xml_load_string($file);
	}
}
?>